@@ -36,7 +36,7 @@ from .asset import Asset
 from .errors import ClientException, NoMoreItems
 from .webhook import Webhook
 
-__all__ = [
+__all__ = (
     'TextChannel',
     'VoiceChannel',
     'DMChannel',
@@ -44,7 +44,7 @@ __all__ = [
     'StoreChannel',
     'GroupChannel',
     '_channel_factory',
-]
+)
 
 async def _single_delete_strategy(messages):
     for m in messages:
@@ -146,8 +146,7 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
 
     def is_nsfw(self):
         """Checks if the channel is NSFW."""
-        n = self.name
-        return self.nsfw or n == 'nsfw' or n[:5] == 'nsfw-'
+        return self.nsfw
 
     def is_news(self):
         """Checks if the channel is a news channel."""
@@ -199,8 +198,8 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
             The new category for this channel. Can be ``None`` to remove the
             category.
         slowmode_delay: :class:`int`
-            Specifies the slowmode rate limit for user in this channel. A value of
-            `0` disables slowmode. The maximum value possible is `120`.
+            Specifies the slowmode rate limit for user in this channel, in seconds.
+            A value of `0` disables slowmode. The maximum value possible is `21600`.
         reason: Optional[:class:`str`]
             The reason for editing this channel. Shows up on the audit log.
 
@@ -215,6 +214,15 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
         """
         await self._edit(options, reason=reason)
 
+    async def clone(self, *, name=None, reason=None):
+        return await self._clone_impl({
+            'topic': self.topic,
+            'nsfw': self.nsfw,
+            'rate_limit_per_user': self.slowmode_delay
+        }, name=name, reason=reason)
+
+    clone.__doc__ = discord.abc.GuildChannel.clone.__doc__
+
     async def delete_messages(self, messages):
         """|coro|
 
@@ -308,7 +316,7 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
             Same as ``around`` in :meth:`history`.
         oldest_first
             Same as ``oldest_first`` in :meth:`history`.
-        bulk: class:`bool`
+        bulk: :class:`bool`
             If True, use bulk delete. bulk=False is useful for mass-deleting
             a bot's own messages without manage_messages. When True, will fall
             back to single delete if current account is a user bot, or if
@@ -395,13 +403,16 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
         data = await self._state.http.channel_webhooks(self.id)
         return [Webhook.from_state(d, state=self._state) for d in data]
 
-    async def create_webhook(self, *, name, avatar=None):
+    async def create_webhook(self, *, name, avatar=None, reason=None):
         """|coro|
 
         Creates a webhook for this channel.
 
         Requires :attr:`~.Permissions.manage_webhooks` permissions.
 
+        .. versionchanged:: 1.1.0
+            Added the ``reason`` keyword-only parameter.
+
         Parameters
         -------------
         name: :class:`str`
@@ -409,6 +420,8 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
         avatar: Optional[:class:`bytes`]
             A :term:`py:bytes-like object` representing the webhook's default avatar.
             This operates similarly to :meth:`~ClientUser.edit`.
+        reason: Optional[:class:`str`]
+            The reason for creating this webhook. Shows up in the audit logs.
 
         Raises
         -------
@@ -426,7 +439,7 @@ class TextChannel(discord.abc.Messageable, discord.abc.GuildChannel, Hashable):
         if avatar is not None:
             avatar = utils._bytes_to_base64_data(avatar)
 
-        data = await self._state.http.create_webhook(self.id, name=str(name), avatar=avatar)
+        data = await self._state.http.create_webhook(self.id, name=str(name), avatar=avatar, reason=reason)
         return Webhook.from_state(data, state=self._state)
 
 class VoiceChannel(discord.abc.Connectable, discord.abc.GuildChannel, Hashable):
@@ -527,6 +540,14 @@ class VoiceChannel(discord.abc.Connectable, discord.abc.GuildChannel, Hashable):
 
     permissions_for.__doc__ = discord.abc.GuildChannel.permissions_for.__doc__
 
+    async def clone(self, *, name=None, reason=None):
+        return await self._clone_impl({
+            'bitrate': self.bitrate,
+            'user_limit': self.user_limit
+        }, name=name, reason=reason)
+
+    clone.__doc__ = discord.abc.GuildChannel.clone.__doc__
+
     async def edit(self, *, reason=None, **options):
         """|coro|
 
@@ -628,8 +649,14 @@ class CategoryChannel(discord.abc.GuildChannel, Hashable):
 
     def is_nsfw(self):
         """Checks if the category is NSFW."""
-        n = self.name
-        return self.nsfw or n == 'nsfw' or n[:5] == 'nsfw-'
+        return self.nsfw
+
+    async def clone(self, *, name=None, reason=None):
+        return await self._clone_impl({
+            'nsfw': self.nsfw
+        }, name=name, reason=reason)
+
+    clone.__doc__ = discord.abc.GuildChannel.clone.__doc__
 
     async def edit(self, *, reason=None, **options):
         """|coro|
@@ -791,8 +818,14 @@ class StoreChannel(discord.abc.GuildChannel, Hashable):
 
     def is_nsfw(self):
         """Checks if the channel is NSFW."""
-        n = self.name
-        return self.nsfw or n == 'nsfw' or n[:5] == 'nsfw-'
+        return self.nsfw
+
+    async def clone(self, *, name=None, reason=None):
+        return await self._clone_impl({
+            'nsfw': self.nsfw
+        }, name=name, reason=reason)
+
+    clone.__doc__ = discord.abc.GuildChannel.clone.__doc__
 
     async def edit(self, *, reason=None, **options):
         """|coro|
