@@ -64,9 +64,6 @@ class Embed:
             Returns the total size of the embed.
             Useful for checking if it's within the 6000 character limit.
 
-    The following attributes can be set during creation
-    of the object:
-
     Certain properties return an ``EmbedProxy``. Which is a type
     that acts similar to a regular :class:`dict` except access the attributes
     via dotted access, e.g. ``embed.author.icon_url``. If the attribute
@@ -80,16 +77,22 @@ class Embed:
     -----------
     title: :class:`str`
         The title of the embed.
+        This can be set during initialisation.
     type: :class:`str`
         The type of embed. Usually "rich".
+        This can be set during initialisation.
     description: :class:`str`
         The description of the embed.
+        This can be set during initialisation.
     url: :class:`str`
         The URL of the embed.
+        This can be set during initialisation.
     timestamp: `datetime.datetime`
         The timestamp of the embed content. This could be a naive or aware datetime.
+        This can be set during initialisation.
     colour: :class:`Colour` or :class:`int`
         The colour code of the embed. Aliased to ``color`` as well.
+        This can be set during initialisation.
     Empty
         A special sentinel value used by ``EmbedProxy`` and this class
         to denote that the value or attribute is empty.
