@@ -132,7 +132,7 @@ class Guild(Hashable):
                  'owner_id', 'mfa_level', 'emojis', 'features',
                  'verification_level', 'explicit_content_filter', 'splash',
                  '_voice_states', '_system_channel_id', 'default_notifications',
-                 'description', 'max_presences', 'max_members')
+                 'description', 'max_presences', 'max_members', 'premium_tier')
 
     def __init__(self, *, data, state):
         self._channels = {}
@@ -237,6 +237,7 @@ class Guild(Hashable):
         self.description = guild.get('description')
         self.max_presences = guild.get('max_presences')
         self.max_members = guild.get('max_members')
+        self.premium_tier = guild.get('premium_tier')
 
         for mdata in guild.get('members', []):
             member = Member(data=mdata, guild=self, state=state)
@@ -675,8 +676,8 @@ class Guild(Hashable):
         topic: Optional[:class:`str`]
             The new channel's topic.
         slowmode_delay: :class:`int`
-            Specifies the slowmode rate limit for user in this channel.
-            The maximum value possible is `120`.
+            Specifies the slowmode rate limit for user in this channel, in seconds.
+            The maximum value possible is `21600`.
         nsfw: :class:`bool`
             To mark the channel as NSFW or not.
         reason: Optional[:class:`str`]
@@ -1021,8 +1022,8 @@ class Guild(Hashable):
                          reason=e['reason'])
                 for e in data]
 
-    async def prune_members(self, *, days, reason=None):
-        """|coro|
+    async def prune_members(self, *, days, compute_prune_count=True, reason=None):
+        r"""|coro|
 
         Prunes the guild from its inactive members.
 
@@ -1041,6 +1042,11 @@ class Guild(Hashable):
             The number of days before counting as inactive.
         reason: Optional[:class:`str`]
             The reason for doing this action. Shows up on the audit log.
+        compute_prune_count: :class:`bool`
+            Whether to compute the prune count. This defaults to ``True``
+            which makes it prone to timeouts in very large guilds. In order
+            to prevent timeouts, you must set this to ``False``. If this is
+            set to ``False``\, then this function will always return ``None``.
 
         Raises
         -------
@@ -1053,14 +1059,15 @@ class Guild(Hashable):
 
         Returns
         ---------
-        :class:`int`
-            The number of members pruned.
+        Optional[:class:`int`]
+            The number of members pruned. If ``compute_prune_count`` is ``False``
+            then this returns ``None``.
         """
 
         if not isinstance(days, int):
             raise InvalidArgument('Expected int for ``days``, received {0.__class__.__name__} instead.'.format(days))
 
-        data = await self._state.http.prune_members(self.id, days, reason=reason)
+        data = await self._state.http.prune_members(self.id, days, compute_prune_count=compute_prune_count, reason=reason)
         return data['pruned']
 
     async def webhooks(self):
