@@ -78,11 +78,7 @@ class BaseUser(_BaseUser):
 
     def __init__(self, *, state, data):
         self._state = state
-        self.name = data['username']
-        self.id = int(data['id'])
-        self.discriminator = data['discriminator']
-        self.avatar = data['avatar']
-        self.bot = data.get('bot', False)
+        self._update(data)
 
     def __str__(self):
         return '{0.name}#{0.discriminator}'.format(self)
@@ -96,6 +92,13 @@ class BaseUser(_BaseUser):
     def __hash__(self):
         return self.id >> 22
 
+    def _update(self, data):
+        self.name = data['username']
+        self.id = int(data['id'])
+        self.discriminator = data['discriminator']
+        self.avatar = data['avatar']
+        self.bot = data.get('bot', False)
+
     @classmethod
     def _copy(cls, user):
         self = cls.__new__(cls) # bypass __init__
@@ -164,7 +167,7 @@ class BaseUser(_BaseUser):
     @property
     def default_avatar(self):
         """Returns the default avatar for a given user. This is calculated by the user's discriminator"""
-        return DefaultAvatar(int(self.discriminator) % len(DefaultAvatar))
+        return try_enum(DefaultAvatar, int(self.discriminator) % len(DefaultAvatar))
 
     @property
     def default_avatar_url(self):
@@ -275,6 +278,8 @@ class ClientUser(BaseUser):
         Specifies if the user is a verified account.
     email: Optional[:class:`str`]
         The email the user used when registering.
+    locale: Optional[:class:`str`]
+        The IETF language tag used to identify the user is using.
     mfa_enabled: :class:`bool`
         Specifies if the user has MFA turned on and working.
     premium: :class:`bool`
@@ -282,25 +287,35 @@ class ClientUser(BaseUser):
     premium_type: :class:`PremiumType`
         Specifies the type of premium a user has (e.g. Nitro or Nitro Classic). Could be None if the user is not premium.
     """
-    __slots__ = ('email', 'verified', 'mfa_enabled', 'premium', 'premium_type', '_relationships')
+    __slots__ = ('email', 'locale', '_flags', 'verified', 'mfa_enabled',
+                 'premium', 'premium_type', '_relationships', '__weakref__')
 
     def __init__(self, *, state, data):
         super().__init__(state=state, data=data)
-        self.verified = data.get('verified', False)
-        self.email = data.get('email')
-        self.mfa_enabled = data.get('mfa_enabled', False)
-        self.premium = data.get('premium', False)
-        self.premium_type = try_enum(PremiumType, data.get('premium_type', None))
         self._relationships = {}
 
     def __repr__(self):
         return '<ClientUser id={0.id} name={0.name!r} discriminator={0.discriminator!r}' \
                ' bot={0.bot} verified={0.verified} mfa_enabled={0.mfa_enabled}>'.format(self)
 
+    def _update(self, data):
+        super()._update(data)
+        # There's actually an Optional[str] phone field as well but I won't use it
+        self.verified = data.get('verified', False)
+        self.email = data.get('email')
+        self.locale = data.get('locale')
+        self._flags = data.get('flags', 0)
+        self.mfa_enabled = data.get('mfa_enabled', False)
+        self.premium = data.get('premium', False)
+        self.premium_type = try_enum(PremiumType, data.get('premium_type', None))
 
     def get_relationship(self, user_id):
         """Retrieves the :class:`Relationship` if applicable.
 
+        .. note::
+
+            This only applies to non-bot accounts.
+
         Parameters
         -----------
         user_id: :class:`int`
@@ -315,17 +330,32 @@ class ClientUser(BaseUser):
 
     @property
     def relationships(self):
-        """Returns a :class:`list` of :class:`Relationship` that the user has."""
+        """Returns a :class:`list` of :class:`Relationship` that the user has.
+
+        .. note::
+
+            This only applies to non-bot accounts.
+        """
         return list(self._relationships.values())
 
     @property
     def friends(self):
-        r"""Returns a :class:`list` of :class:`User`\s that the user is friends with."""
+        r"""Returns a :class:`list` of :class:`User`\s that the user is friends with.
+
+        .. note::
+
+            This only applies to non-bot accounts.
+        """
         return [r.user for r in self._relationships.values() if r.type is RelationshipType.friend]
 
     @property
     def blocked(self):
-        r"""Returns a :class:`list` of :class:`User`\s that the user has blocked."""
+        r"""Returns a :class:`list` of :class:`User`\s that the user has blocked.
+
+        .. note::
+
+            This only applies to non-bot accounts.
+        """
         return [r.user for r in self._relationships.values() if r.type is RelationshipType.blocked]
 
     async def edit(self, **fields):
@@ -425,8 +455,7 @@ class ClientUser(BaseUser):
             except KeyError:
                 pass
 
-        # manually update data by calling __init__ explicitly.
-        self.__init__(state=self._state, data=data)
+        self._update(data)
 
     async def create_group(self, *recipients):
         r"""|coro|
@@ -435,7 +464,9 @@ class ClientUser(BaseUser):
         provided. These recipients must be have a relationship
         of type :attr:`RelationshipType.friend`.
 
-        Bot accounts cannot create a group.
+        .. note::
+
+            This only applies to non-bot accounts.
 
         Parameters
         -----------
@@ -469,7 +500,11 @@ class ClientUser(BaseUser):
     async def edit_settings(self, **kwargs):
         """|coro|
 
-        Edits the client user's settings. Only applicable to user accounts.
+        Edits the client user's settings.
+
+        .. note::
+
+            This only applies to non-bot accounts.
 
         Parameters
         -------
@@ -642,13 +677,22 @@ class User(BaseUser, discord.abc.Messageable):
 
     @property
     def relationship(self):
-        """Returns the :class:`Relationship` with this user if applicable, ``None`` otherwise."""
+        """Returns the :class:`Relationship` with this user if applicable, ``None`` otherwise.
+
+        .. note::
+
+            This only applies to non-bot accounts.
+        """
         return self._state.user.get_relationship(self.id)
 
     async def mutual_friends(self):
         """|coro|
 
-        Gets all mutual friends of this user. This can only be used by non-bot accounts
+        Gets all mutual friends of this user.
+
+        .. note::
+
+            This only applies to non-bot accounts.
 
         Raises
         -------
@@ -667,14 +711,24 @@ class User(BaseUser, discord.abc.Messageable):
         return [User(state=state, data=friend) for friend in mutuals]
 
     def is_friend(self):
-        """:class:`bool`: Checks if the user is your friend."""
+        """:class:`bool`: Checks if the user is your friend.
+
+        .. note::
+
+            This only applies to non-bot accounts.
+        """
         r = self.relationship
         if r is None:
             return False
         return r.type is RelationshipType.friend
 
     def is_blocked(self):
-        """:class:`bool`: Checks if the user is blocked."""
+        """:class:`bool`: Checks if the user is blocked.
+
+        .. note::
+
+            This only applies to non-bot accounts.
+        """
         r = self.relationship
         if r is None:
             return False
@@ -685,6 +739,10 @@ class User(BaseUser, discord.abc.Messageable):
 
         Blocks the user.
 
+        .. note::
+
+            This only applies to non-bot accounts.
+
         Raises
         -------
         Forbidden
@@ -700,6 +758,10 @@ class User(BaseUser, discord.abc.Messageable):
 
         Unblocks the user.
 
+        .. note::
+
+            This only applies to non-bot accounts.
+
         Raises
         -------
         Forbidden
@@ -714,6 +776,10 @@ class User(BaseUser, discord.abc.Messageable):
 
         Removes the user as a friend.
 
+        .. note::
+
+            This only applies to non-bot accounts.
+
         Raises
         -------
         Forbidden
@@ -728,6 +794,10 @@ class User(BaseUser, discord.abc.Messageable):
 
         Sends the user a friend request.
 
+        .. note::
+
+            This only applies to non-bot accounts.
+
         Raises
         -------
         Forbidden
@@ -740,7 +810,11 @@ class User(BaseUser, discord.abc.Messageable):
     async def profile(self):
         """|coro|
 
-        Gets the user's profile. This can only be used by non-bot accounts.
+        Gets the user's profile.
+
+        .. note::
+
+            This only applies to non-bot accounts.
 
         Raises
         -------
